Recipe
Size The number of cells regardless of type.
Cells A cell description.
Network List of incoming connections.
In- and Outputs List of stimuli and probes.
The recipe is the core abstraction to building networks. It declares a number of cells present in the network and will then be interrogated for each about its properties. By asking the recipe about each cell in isolation, Arbor can build the network in parallel while keeping memory consumption low.